import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_autoscaling._jsii
import aws_cdk.aws_autoscaling_hooktargets._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_sns._jsii
import aws_cdk.aws_sns_subscriptions._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-gitlab-runner",
    "1.115.133",
    __name__[0:-6],
    "cdk-gitlab-runner@1.115.133.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
